@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2016, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -26,12 +26,14 @@
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 
 #include "mysys_priv.h"
+#include "my_sys.h"
 #include "mysys_err.h"
 #include <m_ctype.h>
 #include <m_string.h>
 #include <my_dir.h>
 #include <my_xml.h>
-
+#include "mysql/psi/mysql_file.h"
+#include "sql_chars.h"
 
 /*
   The code below implements this functionality:
@@ -65,71 +67,6 @@ get_collation_number_internal(const char *name)
 }
 
 
-static my_bool init_state_maps(CHARSET_INFO *cs)
-{
-  uint i;
-  uchar *state_map;
-  uchar *ident_map;
-
-  if (!(cs->state_map= (uchar*) my_once_alloc(256, MYF(MY_WME))))
-    return 1;
-    
-  if (!(cs->ident_map= (uchar*) my_once_alloc(256, MYF(MY_WME))))
-    return 1;
-
-  state_map= cs->state_map;
-  ident_map= cs->ident_map;
-  
-  /* Fill state_map with states to get a faster parser */
-  for (i=0; i < 256 ; i++)
-  {
-    if (my_isalpha(cs,i))
-      state_map[i]=(uchar) MY_LEX_IDENT;
-    else if (my_isdigit(cs,i))
-      state_map[i]=(uchar) MY_LEX_NUMBER_IDENT;
-#if defined(USE_MB) && defined(USE_MB_IDENT)
-    else if (my_mbcharlen(cs, i)>1)
-      state_map[i]=(uchar) MY_LEX_IDENT;
-#endif
-    else if (my_isspace(cs,i))
-      state_map[i]=(uchar) MY_LEX_SKIP;
-    else
-      state_map[i]=(uchar) MY_LEX_CHAR;
-  }
-  state_map[(uchar)'_']=state_map[(uchar)'$']=(uchar) MY_LEX_IDENT;
-  state_map[(uchar)'\'']=(uchar) MY_LEX_STRING;
-  state_map[(uchar)'.']=(uchar) MY_LEX_REAL_OR_POINT;
-  state_map[(uchar)'>']=state_map[(uchar)'=']=state_map[(uchar)'!']= (uchar) MY_LEX_CMP_OP;
-  state_map[(uchar)'<']= (uchar) MY_LEX_LONG_CMP_OP;
-  state_map[(uchar)'&']=state_map[(uchar)'|']=(uchar) MY_LEX_BOOL;
-  state_map[(uchar)'#']=(uchar) MY_LEX_COMMENT;
-  state_map[(uchar)';']=(uchar) MY_LEX_SEMICOLON;
-  state_map[(uchar)':']=(uchar) MY_LEX_SET_VAR;
-  state_map[0]=(uchar) MY_LEX_EOL;
-  state_map[(uchar)'\\']= (uchar) MY_LEX_ESCAPE;
-  state_map[(uchar)'/']= (uchar) MY_LEX_LONG_COMMENT;
-  state_map[(uchar)'*']= (uchar) MY_LEX_END_LONG_COMMENT;
-  state_map[(uchar)'@']= (uchar) MY_LEX_USER_END;
-  state_map[(uchar) '`']= (uchar) MY_LEX_USER_VARIABLE_DELIMITER;
-  state_map[(uchar)'"']= (uchar) MY_LEX_STRING_OR_DELIMITER;
-
-  /*
-    Create a second map to make it faster to find identifiers
-  */
-  for (i=0; i < 256 ; i++)
-  {
-    ident_map[i]= (uchar) (state_map[i] == MY_LEX_IDENT ||
-			   state_map[i] == MY_LEX_NUMBER_IDENT);
-  }
-
-  /* Special handling of hex and binary strings */
-  state_map[(uchar)'x']= state_map[(uchar)'X']= (uchar) MY_LEX_IDENT_OR_HEX;
-  state_map[(uchar)'b']= state_map[(uchar)'B']= (uchar) MY_LEX_IDENT_OR_BIN;
-  state_map[(uchar)'n']= state_map[(uchar)'N']= (uchar) MY_LEX_IDENT_OR_NCHAR;
-  return 0;
-}
-
-
 static void simple_cs_init_functions(CHARSET_INFO *cs)
 {
   if (cs->state & MY_CS_BINSORT)
@@ -303,7 +240,7 @@ static int add_collation(CHARSET_INFO *cs)
       }
       else
       {
-        uchar *sort_order= all_charsets[cs->number]->sort_order;
+        const uchar *sort_order= all_charsets[cs->number]->sort_order;
         simple_cs_init_functions(all_charsets[cs->number]);
         newcs->mbminlen= 1;
         newcs->mbmaxlen= 1;
@@ -388,13 +325,19 @@ my_once_alloc_c(size_t size)
 
 static void *
 my_malloc_c(size_t size)
-{ return my_malloc(size, MYF(MY_WME)); }
+{ return my_malloc(key_memory_charset_loader, size, MYF(MY_WME)); }
 
 
 static void *
 my_realloc_c(void *old, size_t size)
-{ return my_realloc(old, size, MYF(MY_WME)); }
+{ return my_realloc(key_memory_charset_loader,
+                    old, size, MYF(MY_WME)); }
 
+static void
+my_free_c(void *ptr)
+{
+  my_free(ptr);
+}
 
 /**
   Initialize character set loader to use mysys memory management functions.
@@ -405,9 +348,9 @@ my_charset_loader_init_mysys(MY_CHARSET_LOADER *loader)
 {
   loader->error[0]= '\0';
   loader->once_alloc= my_once_alloc_c;
-  loader->malloc= my_malloc_c;
-  loader->realloc= my_realloc_c;
-  loader->free= my_free;
+  loader->mem_malloc= my_malloc_c;
+  loader->mem_realloc= my_realloc_c;
+  loader->mem_free= my_free_c;
   loader->reporter= my_charset_error_reporter;
   loader->add_collation= add_collation;
 }
@@ -429,7 +372,7 @@ my_read_charset_file(MY_CHARSET_LOADER *loader,
   size_t len, tmp_len;
   MY_STAT stat_info;
 
-  if (!my_stat(filename, &stat_info, myflags))
+  if (!my_stat(filename, &stat_info, MYF(myflags)))
     return TRUE;
 
   len= stat_info.st_size;
@@ -443,7 +386,7 @@ my_read_charset_file(MY_CHARSET_LOADER *loader,
     return TRUE;
   }
 
-  buf= my_malloc(len, myflags);
+  buf= my_malloc(key_memory_charset_file, len, myflags);
   if (!buf)
     return TRUE;
   
@@ -497,39 +440,27 @@ CHARSET_INFO *default_charset_info = &my_charset_latin1;
 
 void add_compiled_collation(CHARSET_INFO *cs)
 {
-  DBUG_ASSERT(cs->number < array_elements(all_charsets));
+  assert(cs->number < array_elements(all_charsets));
   all_charsets[cs->number]= cs;
   cs->state|= MY_CS_AVAILABLE;
 }
 
 
-static my_pthread_once_t charsets_initialized= MY_PTHREAD_ONCE_INIT;
-static my_pthread_once_t charsets_template= MY_PTHREAD_ONCE_INIT;
+static my_thread_once_t charsets_initialized= MY_THREAD_ONCE_INIT;
+static my_thread_once_t charsets_template= MY_THREAD_ONCE_INIT;
 
 static void init_available_charsets(void)
 {
   char fname[FN_REFLEN + sizeof(MY_CHARSET_INDEX)];
-  CHARSET_INFO **cs;
   MY_CHARSET_LOADER loader;
 
   memset(&all_charsets, 0, sizeof(all_charsets));
   init_compiled_charsets(MYF(0));
 
   /* Copy compiled charsets */
-  for (cs=all_charsets;
-       cs < all_charsets+array_elements(all_charsets)-1 ;
-       cs++)
-  {
-    if (*cs)
-    {
-      if (cs[0]->ctype)
-        if (init_state_maps(*cs))
-          *cs= NULL;
-    }
-  }
 
   my_charset_loader_init_mysys(&loader);
-  strmov(get_charsets_dir(fname), MY_CHARSET_INDEX);
+  my_stpcpy(get_charsets_dir(fname), MY_CHARSET_INDEX);
   my_read_charset_file(&loader, fname,
 #ifdef MYSQL_SERVER
                        MYF(MY_WME)
@@ -549,7 +480,7 @@ void free_charsets(void)
 static const char*
 get_collation_name_alias(const char *name, char *buf, size_t bufsize)
 {
-  if (!strncasecmp(name, "utf8mb3_", 8))
+  if (!native_strncasecmp(name, "utf8mb3_", 8))
   {
     my_snprintf(buf, bufsize, "utf8_%s", name + 8);
     return buf;
@@ -562,7 +493,7 @@ uint get_collation_number(const char *name)
 {
   uint id;
   char alias[64];
-  my_pthread_once(&charsets_initialized, init_available_charsets);
+  my_thread_once(&charsets_initialized, init_available_charsets);
   if ((id= get_collation_number_internal(name)))
     return id;
   if ((name= get_collation_name_alias(name, alias, sizeof(alias))))
@@ -600,7 +531,7 @@ get_charset_name_alias(const char *name)
 uint get_charset_number(const char *charset_name, uint cs_flags)
 {
   uint id;
-  my_pthread_once(&charsets_initialized, init_available_charsets);
+  my_thread_once(&charsets_initialized, init_available_charsets);
   if ((id= get_charset_number_internal(charset_name, cs_flags)))
     return id;
   if ((charset_name= get_charset_name_alias(charset_name)))
@@ -611,7 +542,7 @@ uint get_charset_number(const char *charset_name, uint cs_flags)
 
 const char *get_charset_name(uint charset_number)
 {
-  my_pthread_once(&charsets_initialized, init_available_charsets);
+  my_thread_once(&charsets_initialized, init_available_charsets);
 
   if (charset_number < array_elements(all_charsets))
   {
@@ -631,7 +562,7 @@ get_internal_charset(MY_CHARSET_LOADER *loader, uint cs_number, myf flags)
   char  buf[FN_REFLEN];
   CHARSET_INFO *cs;
 
-  DBUG_ASSERT(cs_number < array_elements(all_charsets));
+  assert(cs_number < array_elements(all_charsets));
 
   if ((cs= all_charsets[cs_number]))
   {
@@ -682,7 +613,7 @@ CHARSET_INFO *get_charset(uint cs_number, myf flags)
   if (cs_number == default_charset_info->number)
     return default_charset_info;
 
-  my_pthread_once(&charsets_initialized, init_available_charsets);
+  my_thread_once(&charsets_initialized, init_available_charsets);
  
   if (cs_number >= array_elements(all_charsets)) 
     return NULL;
@@ -693,10 +624,10 @@ CHARSET_INFO *get_charset(uint cs_number, myf flags)
   if (!cs && (flags & MY_WME))
   {
     char index_file[FN_REFLEN + sizeof(MY_CHARSET_INDEX)], cs_string[23];
-    strmov(get_charsets_dir(index_file),MY_CHARSET_INDEX);
+    my_stpcpy(get_charsets_dir(index_file),MY_CHARSET_INDEX);
     cs_string[0]='#';
     int10_to_str(cs_number, cs_string+1, 10);
-    my_error(EE_UNKNOWN_CHARSET, MYF(ME_BELL), cs_string, index_file);
+    my_error(EE_UNKNOWN_CHARSET, MYF(0), cs_string, index_file);
   }
   return cs;
 }
@@ -717,7 +648,7 @@ my_collation_get_by_name(MY_CHARSET_LOADER *loader,
 {
   uint cs_number;
   CHARSET_INFO *cs;
-  my_pthread_once(&charsets_initialized, init_available_charsets);
+  my_thread_once(&charsets_initialized, init_available_charsets);
 
   cs_number= get_collation_number(name);
   my_charset_loader_init_mysys(loader);
@@ -726,8 +657,8 @@ my_collation_get_by_name(MY_CHARSET_LOADER *loader,
   if (!cs && (flags & MY_WME))
   {
     char index_file[FN_REFLEN + sizeof(MY_CHARSET_INDEX)];
-    strmov(get_charsets_dir(index_file),MY_CHARSET_INDEX);
-    my_error(EE_UNKNOWN_COLLATION, MYF(ME_BELL), name, index_file);
+    my_stpcpy(get_charsets_dir(index_file),MY_CHARSET_INDEX);
+    my_error(EE_UNKNOWN_COLLATION, MYF(0), name, index_file);
   }
   return cs;
 }
@@ -759,7 +690,7 @@ my_charset_get_by_name(MY_CHARSET_LOADER *loader,
   DBUG_ENTER("get_charset_by_csname");
   DBUG_PRINT("enter",("name: '%s'", cs_name));
 
-  my_pthread_once(&charsets_initialized, init_available_charsets);
+  my_thread_once(&charsets_initialized, init_available_charsets);
 
   cs_number= get_charset_number(cs_name, cs_flags);
   cs= cs_number ? get_internal_charset(loader, cs_number, flags) : NULL;
@@ -767,8 +698,8 @@ my_charset_get_by_name(MY_CHARSET_LOADER *loader,
   if (!cs && (flags & MY_WME))
   {
     char index_file[FN_REFLEN + sizeof(MY_CHARSET_INDEX)];
-    strmov(get_charsets_dir(index_file),MY_CHARSET_INDEX);
-    my_error(EE_UNKNOWN_CHARSET, MYF(ME_BELL), cs_name, index_file);
+    my_stpcpy(get_charsets_dir(index_file),MY_CHARSET_INDEX);
+    my_error(EE_UNKNOWN_CHARSET, MYF(0), cs_name, index_file);
   }
 
   DBUG_RETURN(cs);
@@ -880,13 +811,10 @@ size_t escape_string_for_mysql(const CHARSET_INFO *charset_info,
   const char *to_start= to;
   const char *end, *to_end=to_start + (to_length ? to_length-1 : 2*length);
   my_bool overflow= FALSE;
-#ifdef USE_MB
   my_bool use_mb_flag= use_mb(charset_info);
-#endif
   for (end= from + length; from < end; from++)
   {
     char escape= 0;
-#ifdef USE_MB
     int tmp_length;
     if (use_mb_flag && (tmp_length= my_ismbchar(charset_info, from, end)))
     {
@@ -911,10 +839,10 @@ size_t escape_string_for_mysql(const CHARSET_INFO *charset_info,
      multi-byte character into a valid one. For example, 0xbf27 is not
      a valid GBK character, but 0xbf5c is. (0x27 = ', 0x5c = \)
     */
-    if (use_mb_flag && (tmp_length= my_mbcharlen(charset_info, *from)) > 1)
+    tmp_length= use_mb_flag ? my_mbcharlen_ptr(charset_info, from, end) : 0;
+    if (tmp_length > 1)
       escape= *from;
     else
-#endif
     switch (*from) {
     case 0:				/* Must be escaped for 'mysql' */
       escape= '0';
@@ -963,7 +891,7 @@ size_t escape_string_for_mysql(const CHARSET_INFO *charset_info,
 }
 
 
-#ifdef BACKSLASH_MBTAIL
+#ifdef _WIN32
 static CHARSET_INFO *fs_cset_cache= NULL;
 
 CHARSET_INFO *fs_character_set()
@@ -1001,11 +929,12 @@ CHARSET_INFO *fs_character_set()
     to_length           Length of destination buffer, or 0
     from                The string to escape
     length              The length of the string to escape
+    quote               The quote the buffer will be escaped against
 
   DESCRIPTION
-    This escapes the contents of a string by doubling up any apostrophes that
-    it contains. This is used when the NO_BACKSLASH_ESCAPES SQL_MODE is in
-    effect on the server.
+    This escapes the contents of a string by doubling up any character
+    specified by the quote parameter. This is used when the
+    NO_BACKSLASH_ESCAPES SQL_MODE is in effect on the server.
 
   NOTE
     To be consistent with escape_string_for_mysql(), to_length may be 0 to
@@ -1018,17 +947,14 @@ CHARSET_INFO *fs_character_set()
 
 size_t escape_quotes_for_mysql(CHARSET_INFO *charset_info,
                                char *to, size_t to_length,
-                               const char *from, size_t length)
+                               const char *from, size_t length, char quote)
 {
   const char *to_start= to;
   const char *end, *to_end=to_start + (to_length ? to_length-1 : 2*length);
   my_bool overflow= FALSE;
-#ifdef USE_MB
   my_bool use_mb_flag= use_mb(charset_info);
-#endif
   for (end= from + length; from < end; from++)
   {
-#ifdef USE_MB
     int tmp_length;
     if (use_mb_flag && (tmp_length= my_ismbchar(charset_info, from, end)))
     {
@@ -1047,16 +973,15 @@ size_t escape_quotes_for_mysql(CHARSET_INFO *charset_info,
       turned into a multi-byte character by the addition of an escaping
       character, because we are only escaping the ' character with itself.
      */
-#endif
-    if (*from == '\'')
+    if (*from == quote)
     {
       if (to + 2 > to_end)
       {
         overflow= TRUE;
         break;
       }
-      *to++= '\'';
-      *to++= '\'';
+      *to++= quote;
+      *to++= quote;
     }
     else
     {
@@ -1071,22 +996,3 @@ size_t escape_quotes_for_mysql(CHARSET_INFO *charset_info,
   *to= 0;
   return overflow ? (ulong)~0 : (ulong) (to - to_start);
 }
-
-#if defined(EXPORT_SYMVER16)
-#ifndef EMBEDDED_LIBRARY
-
-// Hack to provide Fedora symbols
-
-CHARSET_INFO *mysql_get_charset(uint cs_number, myf flags)
-{
-  return get_charset(cs_number, flags);
-}
-
-
-CHARSET_INFO * mysql_get_charset_by_csname(const char *cs_name, uint cs_flags, myf flags)
-{
-  return get_charset_by_csname(cs_name, cs_flags, flags);
-}
-
-#endif
-#endif  /* EXPORT_SYMVER16 */
