@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2002, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -423,8 +423,8 @@ int my_handle_options(int *argc, char ***argv,
   bool opt_found;
 
   /* handle_options() assumes arg0 (program name) always exists */
-  DBUG_ASSERT(argc && *argc >= 1);
-  DBUG_ASSERT(argv && *argv);
+  assert(argc && *argc >= 1);
+  assert(argv && *argv);
   (*argc)--; /* Skip the program name */
   (*argv)++; /*      --- || ----      */
   init_variables(longopts, init_one_value);
@@ -757,10 +757,10 @@ int my_handle_options(int *argc, char ***argv,
                 Hack the string "-XYZ" to make a "-YZ" substring in it,
                 and push that to the output as an unrecognized parameter.
               */
-              DBUG_ASSERT(optend > *pos);
-              DBUG_ASSERT(optend >= cur_arg);
-              DBUG_ASSERT(optend <= *pos + strlen(*pos));
-              DBUG_ASSERT(*optend);
+              assert(optend > *pos);
+              assert(optend >= cur_arg);
+              assert(optend <= *pos + strlen(*pos));
+              assert(*optend);
               optend--;
               optend[0]= '-'; /* replace 'X' or '-' by '-' */
               (*argv)[argvpos++]= optend;
@@ -1361,7 +1361,7 @@ ulonglong max_of_int_range(int var_type)
   case GET_ULL:
     return ULLONG_MAX;
   default:
-    DBUG_ASSERT(0);
+    assert(0);
     return 0;
   }
 }
