@@ -556,7 +556,7 @@ char *audit_log_audit_record(char *buf, size_t buflen,
                               orig_argc - 1, orig_argv + 1));
 
   /* make sure that record is not truncated */
-  DBUG_ASSERT(buf + *outlen <= buf + buflen);
+  assert(buf + *outlen <= buf + buflen);
 
   return buf;
 }
@@ -693,7 +693,7 @@ char *audit_log_general_record(char *buf, size_t buflen,
                     status, query, user, host, external_user, ip, db);
 
   /* make sure that record is not truncated */
-  DBUG_ASSERT(endptr + *outlen <= buf + buflen);
+  assert(endptr + *outlen <= buf + buflen);
 
   return endptr;
 }
@@ -774,7 +774,7 @@ char *audit_log_connection_record(char *buf, size_t buflen,
   database= escape_string(event->database.str, event->database.length,
                           endptr, endbuf - endptr, &endptr, NULL);
 
-  DBUG_ASSERT((endptr - buf) * 2 +
+  assert((endptr - buf) * 2 +
               strlen(format_string[audit_log_format]) +
               strlen(name) +
               MAX_RECORD_ID_SIZE +
@@ -793,7 +793,7 @@ char *audit_log_connection_record(char *buf, size_t buflen,
                     proxy_user, host, ip, database);
 
   /* make sure that record is not truncated */
-  DBUG_ASSERT(endptr + *outlen <= buf + buflen);
+  assert(endptr + *outlen <= buf + buflen);
 
   return endptr;
 }
@@ -809,7 +809,7 @@ size_t audit_log_header(MY_STAT *stat, char *buf, size_t buflen)
                      "",
                      "" };
 
-  DBUG_ASSERT(strcmp(system_charset_info->csname, "utf8") == 0);
+  assert(strcmp(system_charset_info->csname, "utf8") == 0);
 
   log_file_time= stat->st_mtime;
 
@@ -1150,13 +1150,13 @@ my_bool audit_log_update_thd_local(MYSQL_THD thd,
                                    unsigned int event_class,
                                    const void *event)
 {
-  DBUG_ASSERT(audit_log_include_accounts == NULL ||
+  assert(audit_log_include_accounts == NULL ||
               audit_log_exclude_accounts == NULL);
 
-  DBUG_ASSERT(audit_log_include_databases == NULL ||
+  assert(audit_log_include_databases == NULL ||
               audit_log_exclude_databases == NULL);
 
-  DBUG_ASSERT(audit_log_include_commands == NULL ||
+  assert(audit_log_include_commands == NULL ||
               audit_log_exclude_commands == NULL);
 
   if (event_class == MYSQL_AUDIT_CONNECTION_CLASS)
@@ -1200,7 +1200,7 @@ my_bool audit_log_update_thd_local(MYSQL_THD thd,
     if (event_connection->status == 0)
     {
       /* track default DB change */
-      DBUG_ASSERT(event_connection->database.length <= sizeof(local->db));
+      assert(event_connection->database.length <= sizeof(local->db));
       memcpy(local->db, event_connection->database.str,
              event_connection->database.length);
       local->db[event_connection->database.length]= 0;
@@ -1264,7 +1264,7 @@ my_bool audit_log_update_thd_local(MYSQL_THD thd,
       /* Database is about to be changed. Server doesn't provide database
       name in STATUS event, so remember it now. */
 
-      DBUG_ASSERT(event_general->general_query.length <= sizeof(local->db));
+      assert(event_general->general_query.length <= sizeof(local->db));
       memcpy(local->db, event_general->general_query.str,
              event_general->general_query.length);
       local->db[event_general->general_query.length]= 0;
@@ -1385,7 +1385,7 @@ int audit_log_notify(MYSQL_THD thd MY_ATTRIBUTE((unused)),
                                           event_general->general_error_code,
                                           event_general, local->db,
                                           &len);
-        DBUG_ASSERT(log_rec);
+        assert(log_rec);
       }
       if (log_rec)
         audit_log_write(log_rec, len);
@@ -1624,7 +1624,7 @@ void audit_log_exclude_accounts_update(
 {
   const char *new_val= *(const char **)(save);
 
-  DBUG_ASSERT(audit_log_include_accounts == NULL);
+  assert(audit_log_include_accounts == NULL);
 
   my_free(audit_log_exclude_accounts);
   audit_log_exclude_accounts= NULL;
@@ -1679,7 +1679,7 @@ void audit_log_include_accounts_update(
 {
   const char *new_val= *(const char **)(save);
 
-  DBUG_ASSERT(audit_log_exclude_accounts == NULL);
+  assert(audit_log_exclude_accounts == NULL);
 
   my_free(audit_log_include_accounts);
   audit_log_include_accounts= NULL;
@@ -1733,7 +1733,7 @@ void audit_log_exclude_databases_update(
 {
   const char *new_val= *(const char **)(save);
 
-  DBUG_ASSERT(audit_log_include_databases == NULL);
+  assert(audit_log_include_databases == NULL);
 
   my_free(audit_log_exclude_databases);
   audit_log_exclude_databases= NULL;
@@ -1788,7 +1788,7 @@ void audit_log_include_databases_update(
 {
   const char *new_val= *(const char **)(save);
 
-  DBUG_ASSERT(audit_log_exclude_databases == NULL);
+  assert(audit_log_exclude_databases == NULL);
 
   my_free(audit_log_include_databases);
   audit_log_include_databases= NULL;
@@ -1842,7 +1842,7 @@ void audit_log_exclude_commands_update(
 {
   const char *new_val= *(const char **)(save);
 
-  DBUG_ASSERT(audit_log_include_commands == NULL);
+  assert(audit_log_include_commands == NULL);
 
   my_free(audit_log_exclude_commands);
   audit_log_exclude_commands= NULL;
@@ -1897,7 +1897,7 @@ void audit_log_include_commands_update(
 {
   const char *new_val= *(const char **)(save);
 
-  DBUG_ASSERT(audit_log_exclude_commands == NULL);
+  assert(audit_log_exclude_commands == NULL);
 
   my_free(audit_log_include_commands);
   audit_log_include_commands= NULL;
