@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2019, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -331,7 +331,7 @@ bool log_syslog_update_settings()
 
     SYSLOG_FACILITY rsf = { LOG_DAEMON, "daemon" };
 
-    DBUG_ASSERT(opt_log_syslog_facility != NULL);
+    assert(opt_log_syslog_facility != NULL);
 
     if (log_syslog_find_facility(opt_log_syslog_facility, &rsf))
     {
@@ -462,8 +462,8 @@ bool log_syslog_init(void)
 
 static void ull2timeval(ulonglong utime, struct timeval *tv)
 {
-  DBUG_ASSERT(tv != NULL);
-  DBUG_ASSERT(utime > 0);      /* should hold true in this context */
+  assert(tv != NULL);
+  assert(utime > 0);      /* should hold true in this context */
   tv->tv_sec= static_cast<long>(utime / 1000000);
   tv->tv_usec=utime % 1000000;
 }
@@ -582,9 +582,9 @@ static File mysql_file_real_name_reopen(File file,
                                         const char *opened_file_name,
                                         char *real_file_name)
 {
-  DBUG_ASSERT(file);
-  DBUG_ASSERT(opened_file_name);
-  DBUG_ASSERT(real_file_name);
+  assert(file);
+  assert(opened_file_name);
+  assert(real_file_name);
 
 #ifdef _WIN32
   /* On Windows, O_NOFOLLOW is not supported. Verify real path from fd. */
@@ -643,8 +643,8 @@ bool File_query_log::open()
   else if (m_log_type == QUERY_LOG_GENERAL)
     log_name= opt_general_logname;
   else
-    DBUG_ASSERT(false);
-  DBUG_ASSERT(log_name && log_name[0]);
+    assert(false);
+  assert(log_name && log_name[0]);
 
   write_error= false;
 
@@ -813,7 +813,7 @@ bool File_query_log::write_general(ulonglong event_utime,
   size_t length= 0;
 
   mysql_mutex_lock(&LOCK_log);
-  DBUG_ASSERT(is_open());
+  assert(is_open());
 
   /* Note that my_b_write() assumes it knows the length for this */
   char local_time_buff[iso8601_size];
@@ -869,7 +869,7 @@ bool File_query_log::write_slow(THD *thd, ulonglong current_utime,
   end= buff;
 
   mysql_mutex_lock(&LOCK_log);
-  DBUG_ASSERT(is_open());
+  assert(is_open());
 
   if ((max_slowlog_size > 0) && rotate(max_slowlog_size, &need_purge))
     goto err;
@@ -1092,6 +1092,9 @@ bool Log_to_csv_event_handler::log_general(THD *thd, ulonglong event_utime,
 
   ulonglong save_thd_options= thd->variables.option_bits;
   thd->variables.option_bits&= ~OPTION_BIN_LOG;
+#ifdef WITH_WSREP
+  thd->variables.option_bits|= OPTION_BIN_LOG_INTERNAL_OFF;
+#endif
 
   TABLE_LIST table_list;
   table_list.init_one_table(MYSQL_SCHEMA_NAME.str, MYSQL_SCHEMA_NAME.length,
@@ -1141,7 +1144,7 @@ bool Log_to_csv_event_handler::log_general(THD *thd, ulonglong event_utime,
     default value (which is CURRENT_TIMESTAMP).
   */
 
-  DBUG_ASSERT(table->field[GLT_FIELD_EVENT_TIME]->type() == MYSQL_TYPE_TIMESTAMP);
+  assert(table->field[GLT_FIELD_EVENT_TIME]->type() == MYSQL_TYPE_TIMESTAMP);
   ull2timeval(event_utime, &tv);
   table->field[GLT_FIELD_EVENT_TIME]->store_timestamp(&tv);
 
@@ -1259,7 +1262,7 @@ bool Log_to_csv_event_handler::log_slow(THD *thd, ulonglong current_utime,
   restore_record(table, s->default_values);    // Get empty record
 
   /* store the time and user values */
-  DBUG_ASSERT(table->field[SQLT_FIELD_START_TIME]->type() == MYSQL_TYPE_TIMESTAMP);
+  assert(table->field[SQLT_FIELD_START_TIME]->type() == MYSQL_TYPE_TIMESTAMP);
   ull2timeval(current_utime, &tv);
   table->field[SQLT_FIELD_START_TIME]->store_timestamp(&tv);
 
@@ -1404,7 +1407,7 @@ bool Log_to_csv_event_handler::activate_log(THD *thd,
                               SLOW_LOG_NAME.str, TL_WRITE_CONCURRENT_INSERT);
     break;
   default:
-    DBUG_ASSERT(false);
+    assert(false);
   }
 
   Open_tables_backup open_tables_backup;
@@ -1469,7 +1472,7 @@ void Query_logger::cleanup()
 {
   mysql_rwlock_destroy(&LOCK_logger);
 
-  DBUG_ASSERT(file_log_handler);
+  assert(file_log_handler);
   file_log_handler->cleanup();
   delete file_log_handler;
   file_log_handler= NULL;
@@ -1479,7 +1482,7 @@ void Query_logger::cleanup()
 bool Query_logger::slow_log_write(THD *thd, const char *query,
                                   size_t query_length)
 {
-  DBUG_ASSERT(thd->enable_slow_log);
+  assert(thd->enable_slow_log);
 
   if (!(*slow_log_handler_list))
     return false;
@@ -1706,7 +1709,7 @@ void Query_logger::init_query_log(enum_log_table_type log_type,
     }
   }
   else
-    DBUG_ASSERT(false);
+    assert(false);
 }
 
 
@@ -1815,7 +1818,7 @@ char *make_query_log_name(char *buff, enum_log_table_type log_type)
   else if (log_type == QUERY_LOG_SLOW)
     log_ext= "-slow.log";
   else
-    DBUG_ASSERT(false);
+    assert(false);
 
   strmake(buff, default_logfile_name, FN_REFLEN-5);
   return fn_format(buff, buff, mysql_real_data_home, log_ext,
@@ -1839,7 +1842,7 @@ static ulonglong get_query_exec_time(THD *thd, ulonglong cur_utime)
 {
   ulonglong res;
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   if (thd->variables.query_exec_time != 0)
     res= thd->lex->sql_command != SQLCOM_SET_OPTION ?
       thd->variables.query_exec_time : 0;
@@ -2323,7 +2326,7 @@ void flush_error_log_messages()
 
 void init_error_log()
 {
-  DBUG_ASSERT(!error_log_initialized);
+  assert(!error_log_initialized);
   mysql_mutex_init(key_LOCK_error_log, &LOCK_error_log, MY_MUTEX_INIT_FAST);
   error_log_initialized= true;
 }
@@ -2331,7 +2334,7 @@ void init_error_log()
 
 bool open_error_log(const char *filename, bool get_lock)
 {
-  DBUG_ASSERT(filename);
+  assert(filename);
   int retries= 2, errors= 0;
 
   do
@@ -2373,7 +2376,7 @@ bool open_error_log(const char *filename, bool get_lock)
 void destroy_error_log()
 {
   // We should have flushed before this...
-  DBUG_ASSERT(!error_log_buffering);
+  assert(!error_log_buffering);
   // ... but play it safe on release builds
   flush_error_log_messages();
   if (error_log_initialized)
@@ -2534,7 +2537,7 @@ int my_plugin_log_message(MYSQL_PLUGIN *plugin_ptr, plugin_log_level level,
   struct st_plugin_int *plugin = static_cast<st_plugin_int *> (*plugin_ptr);
   va_list args;
 
-  DBUG_ASSERT(level >= MY_ERROR_LEVEL || level <= MY_INFORMATION_LEVEL);
+  assert(level >= MY_ERROR_LEVEL || level <= MY_INFORMATION_LEVEL);
 
   switch (level)
   {
