@@ -1,4 +1,4 @@
-/* Copyright (c) 2013, 2018, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2013, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -215,7 +215,7 @@ public:
     if (pc->select->master_unit()->is_union() && !pc->select->braces)
     {
       pc->select= pc->select->master_unit()->fake_select_lex;
-      DBUG_ASSERT(pc->select != NULL);
+      assert(pc->select != NULL);
     }
 
     if (limit_options.is_offset_first && limit_options.opt_offset != NULL &&
@@ -322,11 +322,11 @@ public:
   : tab1_node(tab1_node_arg), join_pos(join_pos_arg), tab2_node(tab2_node_arg),
     tr1(NULL), tr2(NULL)
   {
-    DBUG_ASSERT(dbug_exclusive_flags(JTT_NORMAL | JTT_STRAIGHT | JTT_NATURAL));
-    DBUG_ASSERT(dbug_exclusive_flags(JTT_LEFT | JTT_RIGHT));
+    assert(dbug_exclusive_flags(JTT_NORMAL | JTT_STRAIGHT | JTT_NATURAL));
+    assert(dbug_exclusive_flags(JTT_LEFT | JTT_RIGHT));
   }
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   bool dbug_exclusive_flags(unsigned int mask)
   {
 #ifdef __GNUC__
@@ -350,7 +350,7 @@ public:
       {
         TABLE_LIST *inner_table= pc->select->convert_right_join();
         /* swap tr1 and tr2 */
-        DBUG_ASSERT(inner_table == tr1);
+        assert(inner_table == tr1);
         tr1= tr2;
         tr2= inner_table;
       }
@@ -416,11 +416,11 @@ public:
 
     if (super::contextualize(pc) || on->itemize(pc, &on))
       return true;
-    DBUG_ASSERT(sel == pc->select);
+    assert(sel == pc->select);
 
     add_join_on(this->tr2, on);
     pc->thd->lex->pop_context();
-    DBUG_ASSERT(sel->parsing_place == CTX_ON);
+    assert(sel->parsing_place == CTX_ON);
     sel->parsing_place= CTX_NONE;
     return false;
   }
@@ -511,10 +511,10 @@ public:
 
     if (select_item_list->contextualize(pc))
       return true;
-    DBUG_ASSERT(select == pc->select);
+    assert(select == pc->select);
 
     // Ensure we're resetting parsing place of the right select
-    DBUG_ASSERT(select->parsing_place == CTX_SELECT_LIST);
+    assert(select->parsing_place == CTX_SELECT_LIST);
     select->parsing_place= CTX_NONE;
     return false;
   }
@@ -627,7 +627,7 @@ public:
     if (super::contextualize(pc))
       return true;
 
-    DBUG_ASSERT(pc->select->linkage != GLOBAL_OPTIONS_TYPE);
+    assert(pc->select->linkage != GLOBAL_OPTIONS_TYPE);
     SELECT_LEX *fake= pc->select->master_unit()->fake_select_lex;
     if (fake)
     {
@@ -1558,14 +1558,14 @@ public:
     if (!user->user.str)
     {
       LEX_CSTRING sctx_priv_user= thd->security_context()->priv_user();
-      DBUG_ASSERT(sctx_priv_user.str);
+      assert(sctx_priv_user.str);
       user->user.str= sctx_priv_user.str;
       user->user.length= sctx_priv_user.length;
     }
     if (!user->host.str)
     {
       LEX_CSTRING sctx_priv_host= thd->security_context()->priv_host();
-      DBUG_ASSERT(sctx_priv_host.str);
+      assert(sctx_priv_host.str);
       user->host.str= (char *) sctx_priv_host.str;
       user->host.length= sctx_priv_host.length;
     }
@@ -1627,12 +1627,12 @@ public:
       return true;
 
     THD *thd= pc->thd;
-#ifndef DBUG_OFF
+#ifndef NDEBUG
     LEX *old_lex= thd->lex;
-#endif//DBUG_OFF
+#endif//NDEBUG
 
     sp_create_assignment_lex(thd, delimiter_pos.raw.end);
-    DBUG_ASSERT(thd->lex->select_lex == thd->lex->current_select());
+    assert(thd->lex->select_lex == thd->lex->current_select());
     Parse_context inner_pc(pc->thd, thd->lex->select_lex);
 
     if (value->contextualize(&inner_pc))
@@ -1640,8 +1640,8 @@ public:
 
     if (sp_create_assignment_instr(pc->thd, value_pos.raw.end))
       return true;
-    DBUG_ASSERT(thd->lex == old_lex &&
-                thd->lex->current_select() == pc->select);
+    assert(thd->lex == old_lex &&
+           thd->lex->current_select() == pc->select);
 
     return false;
   }
@@ -1690,7 +1690,7 @@ public:
 
     if (sp_create_assignment_instr(pc->thd, head_pos.raw.end))
       return true;
-    DBUG_ASSERT(pc->thd->lex->select_lex == pc->thd->lex->current_select());
+    assert(pc->thd->lex->select_lex == pc->thd->lex->current_select());
     pc->select= pc->thd->lex->select_lex;
 
     if (tail != NULL && tail->contextualize(pc))
@@ -1806,7 +1806,7 @@ public:
 
     if (sp_create_assignment_instr(thd, end_pos.raw.end))
       return true;
-    DBUG_ASSERT(pc->thd->lex->select_lex == pc->thd->lex->current_select());
+    assert(pc->thd->lex->select_lex == pc->thd->lex->current_select());
     pc->select= pc->thd->lex->select_lex;
 
     return false;
@@ -1843,7 +1843,7 @@ public:
 
     if (sp_create_assignment_instr(pc->thd, head_pos.raw.end))
       return true; 
-    DBUG_ASSERT(pc->thd->lex->select_lex == pc->thd->lex->current_select());
+    assert(pc->thd->lex->select_lex == pc->thd->lex->current_select());
     pc->select= pc->thd->lex->select_lex;
 
     if (opt_tail != NULL && opt_tail->contextualize(pc))
@@ -1877,7 +1877,7 @@ public:
 
     if (sp_create_assignment_instr(pc->thd, characteristics_pos.raw.end))
       return true; 
-    DBUG_ASSERT(pc->thd->lex->select_lex == pc->thd->lex->current_select());
+    assert(pc->thd->lex->select_lex == pc->thd->lex->current_select());
     pc->select= pc->thd->lex->select_lex;
 
     return false;
@@ -1957,7 +1957,7 @@ public:
     {
       sp_create_assignment_lex(thd, set_pos.raw.end);
     }
-    DBUG_ASSERT(pc->thd->lex->select_lex == pc->thd->lex->current_select());
+    assert(pc->thd->lex->select_lex == pc->thd->lex->current_select());
     pc->select= pc->thd->lex->select_lex;
 
     return list->contextualize(pc);
@@ -2098,7 +2098,7 @@ public:
   explicit PT_select_var(const LEX_STRING &name_arg) : name(name_arg) {}
 
   virtual bool is_local() const { return false; }
-  virtual uint get_offset() const { DBUG_ASSERT(0); return 0; }
+  virtual uint get_offset() const { assert(0); return 0; }
 };
 
 
@@ -2108,7 +2108,7 @@ class PT_select_sp_var : public PT_select_var
 
   uint offset;
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   /*
     Routine to which this Item_splocal belongs. Used for checking if correct
     runtime context is used for variable handling.
@@ -2128,7 +2128,7 @@ public:
       return true;
 
     LEX *lex= pc->thd->lex;
-#ifndef DBUG_OFF
+#ifndef NDEBUG
     sp= lex->sphead;
 #endif
     sp_pcontext *pctx= lex->get_sp_current_parsing_ctx();
@@ -2219,7 +2219,7 @@ public:
       return true;
 
     // Ensure we're resetting parsing place of the right select
-    DBUG_ASSERT(pc->select->parsing_place == CTX_SELECT_LIST);
+    assert(pc->select->parsing_place == CTX_SELECT_LIST);
     pc->select->parsing_place= CTX_NONE;
     return false;
   }
@@ -2311,9 +2311,9 @@ public:
          opt_into2->contextualize(pc)))
       return true;
 
-    DBUG_ASSERT(opt_into1 == NULL || opt_into2 == NULL);
-    DBUG_ASSERT(opt_procedure_analyse_clause == NULL ||
-                (opt_into1 == NULL && opt_into2 == NULL));
+    assert(opt_into1 == NULL || opt_into2 == NULL);
+    assert(opt_procedure_analyse_clause == NULL ||
+           (opt_into1 == NULL && opt_into2 == NULL));
 
     /*
       @todo: explain should not affect how we construct the query data
@@ -2514,7 +2514,7 @@ public:
 
   bool is_multitable() const
   {
-    DBUG_ASSERT((table_ident != NULL) ^ (table_list.size() > 0));
+    assert((table_ident != NULL) ^ (table_list.size() > 0));
     return table_ident == NULL;
   }
 
@@ -2603,7 +2603,7 @@ public:
 
   virtual List<List_item> &get_many_values()
   {
-    DBUG_ASSERT(is_contextualized());
+    assert(is_contextualized());
     return many_values;
   }
 };
@@ -2671,16 +2671,16 @@ public:
     opt_on_duplicate_value_list(opt_on_duplicate_value_list_arg)
   {
     // REPLACE statement can't have IGNORE flag:
-    DBUG_ASSERT(!is_replace || !ignore);
+    assert(!is_replace || !ignore);
     // REPLACE statement can't have ON DUPLICATE KEY UPDATE clause:
-    DBUG_ASSERT(!is_replace || opt_on_duplicate_column_list == NULL);
+    assert(!is_replace || opt_on_duplicate_column_list == NULL);
     // INSERT/REPLACE ... SELECT can't have VALUES clause:
-    DBUG_ASSERT((row_value_list != NULL) ^ (insert_query_expression != NULL));
+    assert((row_value_list != NULL) ^ (insert_query_expression != NULL));
     // ON DUPLICATE KEY UPDATE: column and value arrays must have same sizes:
-    DBUG_ASSERT((opt_on_duplicate_column_list == NULL &&
-                 opt_on_duplicate_value_list == NULL) ||
-                (opt_on_duplicate_column_list->elements() ==
-                 opt_on_duplicate_value_list->elements()));
+    assert((opt_on_duplicate_column_list == NULL &&
+            opt_on_duplicate_value_list == NULL) ||
+           (opt_on_duplicate_column_list->elements() ==
+            opt_on_duplicate_value_list->elements()));
   }
 
   virtual bool contextualize(Parse_context *pc);
