@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+   Copyright (c) 2007, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -104,8 +104,8 @@ int get_or_create_user_conn(THD *thd, const char *user,
   char temp_user[USER_HOST_BUFF_SIZE];
   struct  user_conn *uc;
 
-  DBUG_ASSERT(user != 0);
-  DBUG_ASSERT(host != 0);
+  assert(user != 0);
+  assert(host != 0);
 
   user_len= strlen(user);
   temp_len= (my_stpcpy(my_stpcpy(temp_user, user)+1, host) - temp_user)+1;
@@ -839,7 +839,7 @@ void decrease_user_connections(USER_CONN *uc)
 {
   DBUG_ENTER("decrease_user_connections");
   mysql_mutex_lock(&LOCK_user_conn);
-  DBUG_ASSERT(uc->connections);
+  assert(uc->connections);
   if (!--uc->connections && !mqh_used)
   {
     /* Last connection for user; Delete it */
@@ -865,7 +865,7 @@ void release_user_connection(THD *thd)
   if (uc)
   {
     mysql_mutex_lock(&LOCK_user_conn);
-    DBUG_ASSERT(uc->connections > 0);
+    assert(uc->connections > 0);
     thd->decrement_user_connections_counter();
     if (!uc->connections && !mqh_used)
     {
@@ -891,7 +891,7 @@ bool check_mqh(THD *thd, uint check_command)
   bool error= 0;
   const USER_CONN *uc=thd->get_user_connect();
   DBUG_ENTER("check_mqh");
-  DBUG_ASSERT(uc != 0);
+  assert(uc != 0);
 
   mysql_mutex_lock(&LOCK_user_conn);
 
@@ -1587,9 +1587,11 @@ void close_connection(THD *thd, uint sql_errno,
   if (MYSQL_CONNECTION_DONE_ENABLED())
   {
     sleep(0); /* Workaround to avoid tailcall optimisation */
+#ifdef WITH_WSREP
     mysql_mutex_lock(&thd->LOCK_wsrep_thd);
     wsrep_thd_set_query_state(thd, QUERY_EXITING);
     mysql_mutex_unlock(&thd->LOCK_wsrep_thd);
+#endif /* WITH_WSREP */
   }
 
   if (generate_event)
