@@ -42,7 +42,7 @@ void wsrep_cleanup_transaction(THD *thd)
 
   // Enabling it can cause password to appear in log.
   // WSREP_DEBUG("wsrep_cleanup_transaction %s", thd->query().str);
-  DBUG_ASSERT(thd->wsrep_conflict_state != MUST_REPLAY &&
+  assert(thd->wsrep_conflict_state != MUST_REPLAY &&
               thd->wsrep_conflict_state != REPLAYING);
 
   if (wsrep_emulate_bin_log) wsrep_thd_binlog_trx_reset(thd);
@@ -167,7 +167,7 @@ void wsrep_interim_commit(THD* thd)
   {
   case LOCAL_COMMIT:
     {
-      DBUG_ASSERT(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
+      assert(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
       if (wsrep->interim_commit(wsrep, &thd->wsrep_ws_handle))
       {
         DBUG_PRINT("wsrep", ("set committed fail"));
@@ -200,7 +200,7 @@ void wsrep_post_commit(THD* thd, bool all)
   {
   case LOCAL_COMMIT:
     {
-      DBUG_ASSERT(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
+      assert(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
       if (wsrep->post_commit(wsrep, &thd->wsrep_ws_handle))
       {
         DBUG_PRINT("wsrep", ("set committed fail"));
@@ -315,9 +315,9 @@ static int wsrep_prepare(handlerton *hton, THD *thd, bool all)
     DBUG_RETURN(0);
   }
 
-  DBUG_ASSERT(thd->ha_data[wsrep_hton->slot].ha_info[all].is_trx_read_write());
-  DBUG_ASSERT(thd->wsrep_exec_mode == LOCAL_STATE);
-  DBUG_ASSERT(thd->wsrep_trx_meta.gtid.seqno == WSREP_SEQNO_UNDEFINED);
+  assert(thd->ha_data[wsrep_hton->slot].ha_info[all].is_trx_read_write());
+  assert(thd->wsrep_exec_mode == LOCAL_STATE);
+  assert(thd->wsrep_trx_meta.gtid.seqno == WSREP_SEQNO_UNDEFINED);
 
   if (((all || !thd_test_options(thd, OPTION_NOT_AUTOCOMMIT | OPTION_BEGIN)) &&
        (thd->variables.wsrep_on && !wsrep_trans_cache_is_empty(thd)))        ||
@@ -409,7 +409,7 @@ int wsrep_commit(handlerton *hton, THD *thd, bool all)
   {
     if (thd->wsrep_exec_mode == LOCAL_COMMIT)
     {
-      DBUG_ASSERT(thd->ha_data[wsrep_hton->slot].ha_info[all].is_trx_read_write());
+      assert(thd->ha_data[wsrep_hton->slot].ha_info[all].is_trx_read_write());
       /*
         Call to wsrep->post_commit() (moved to wsrep_post_commit()) must
         be done only after commit has done for all involved htons.
@@ -669,7 +669,7 @@ wsrep_run_wsrep_commit(THD *thd, handlerton *hton, bool all)
                   thd->thread_id(), (long long)thd->wsrep_trx_meta.gtid.seqno);
       mysql_mutex_lock(&thd->LOCK_wsrep_thd);
       thd->wsrep_conflict_state = MUST_REPLAY;
-      DBUG_ASSERT(wsrep_thd_trx_seqno(thd) > 0);
+      assert(wsrep_thd_trx_seqno(thd) > 0);
       mysql_mutex_unlock(&thd->LOCK_wsrep_thd);
       mysql_mutex_lock(&LOCK_wsrep_replaying);
       wsrep_replaying++;
@@ -680,7 +680,7 @@ wsrep_run_wsrep_commit(THD *thd, handlerton *hton, bool all)
   } else {
     WSREP_ERROR("I/O error reading from thd's binlog iocache: "
                 "errno=%d, io cache code=%d", my_errno(), cache->error);
-    DBUG_ASSERT(0); // failure like this can not normally happen
+    assert(0); // failure like this can not normally happen
     DBUG_RETURN(WSREP_TRX_ERROR);
   }
 
@@ -707,7 +707,7 @@ wsrep_run_wsrep_commit(THD *thd, handlerton *hton, bool all)
                  wsrep_get_conflict_state(thd->wsrep_conflict_state));
     }
     thd->wsrep_exec_mode= LOCAL_COMMIT;
-    DBUG_ASSERT(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
+    assert(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
     /* Override XID iff it was generated by mysql */
     if (thd->get_transaction()->xid_state()->get_xid()->is_null() ||
         thd->get_transaction()->xid_state()->get_xid()->get_my_xid())
@@ -728,7 +728,7 @@ wsrep_run_wsrep_commit(THD *thd, handlerton *hton, bool all)
     break;
 
   case WSREP_BF_ABORT:
-    DBUG_ASSERT(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
+    assert(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
 
   case WSREP_TRX_FAIL:
     WSREP_DEBUG("commit action failed for reason: %s THD: %u Query: %s",
@@ -736,7 +736,7 @@ wsrep_run_wsrep_commit(THD *thd, handlerton *hton, bool all)
                 WSREP_QUERY(thd));
     DBUG_PRINT("wsrep", ("replicating commit fail"));
 
-    thd->wsrep_query_state= QUERY_EXEC;
+    wsrep_thd_set_query_state(thd, QUERY_EXEC);
 
     if (thd->wsrep_conflict_state == MUST_ABORT) {
       thd->wsrep_conflict_state= ABORTED;
@@ -771,7 +771,7 @@ wsrep_run_wsrep_commit(THD *thd, handlerton *hton, bool all)
     DBUG_RETURN(WSREP_TRX_ERROR);
   }
 
-  thd->wsrep_query_state= QUERY_EXEC;
+  wsrep_thd_set_query_state(thd, QUERY_EXEC);
   mysql_mutex_unlock(&thd->LOCK_wsrep_thd);
 
   DBUG_RETURN(WSREP_TRX_OK);
@@ -898,7 +898,7 @@ enum wsrep_trx_status wsrep_replicate(THD *thd)
     DBUG_RETURN(WSREP_TRX_CERT_FAIL);
   }
 
-  thd->wsrep_query_state = QUERY_COMMITTING;
+  wsrep_thd_set_query_state(thd, QUERY_COMMITTING);
   mysql_mutex_unlock(&thd->LOCK_wsrep_thd);
 
   DEBUG_SYNC(thd, "wsrep_before_certification");
@@ -955,7 +955,7 @@ enum wsrep_trx_status wsrep_replicate(THD *thd)
     {
       WSREP_DEBUG("empty rbr buffer, query: %s", WSREP_QUERY(thd));
     }
-    thd->wsrep_query_state= QUERY_EXEC;
+    wsrep_thd_set_query_state(thd, QUERY_EXEC);
     DBUG_RETURN(WSREP_TRX_OK);
   }
 
@@ -998,7 +998,7 @@ enum wsrep_trx_status wsrep_replicate(THD *thd)
                   thd->thread_id(), (long long)thd->wsrep_trx_meta.gtid.seqno);
       mysql_mutex_lock(&thd->LOCK_wsrep_thd);
       thd->wsrep_conflict_state = MUST_REPLAY;
-      DBUG_ASSERT(wsrep_thd_trx_seqno(thd) > 0);
+      assert(wsrep_thd_trx_seqno(thd) > 0);
       mysql_mutex_unlock(&thd->LOCK_wsrep_thd);
       mysql_mutex_lock(&LOCK_wsrep_replaying);
       wsrep_replaying++;
@@ -1009,7 +1009,7 @@ enum wsrep_trx_status wsrep_replicate(THD *thd)
   } else {
     WSREP_ERROR("I/O error reading from thd's binlog iocache: "
                 "errno=%d, io cache code=%d", my_errno(), cache->error);
-    DBUG_ASSERT(0); // failure like this can not normally happen
+    assert(0); // failure like this can not normally happen
     DBUG_RETURN(WSREP_TRX_ERROR);
   }
 
@@ -1039,7 +1039,7 @@ enum wsrep_trx_status wsrep_replicate(THD *thd)
     /* We avoid updating the wsrep_exec_mode to LOCAL_COMMIT till we are done
     with pre-commit hook. */
 
-    DBUG_ASSERT(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
+    assert(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
     /* Override XID iff it was generated by mysql */
     if (thd->get_transaction()->xid_state()->get_xid()->is_null() ||
         thd->get_transaction()->xid_state()->get_xid()->get_my_xid())
@@ -1060,7 +1060,7 @@ enum wsrep_trx_status wsrep_replicate(THD *thd)
     break;
 
   case WSREP_BF_ABORT:
-    DBUG_ASSERT(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
+    assert(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
 
   case WSREP_TRX_FAIL:
     WSREP_DEBUG("commit action failed for reason: %s THD: %u Query: %s",
@@ -1117,7 +1117,7 @@ enum wsrep_trx_status wsrep_pre_commit(THD *thd)
 
   DBUG_ENTER("wsrep_pre_commit");
 
-  DBUG_ASSERT(thd->wsrep_query_state == QUERY_COMMITTING);
+  assert(thd->wsrep_query_state == QUERY_COMMITTING);
 
   THD_STAGE_INFO(thd, stage_wsrep_pre_commit);
   snprintf(thd->wsrep_info, sizeof(thd->wsrep_info) - 1,
@@ -1145,7 +1145,7 @@ enum wsrep_trx_status wsrep_pre_commit(THD *thd)
                 thd->thread_id(), (long long)thd->wsrep_trx_meta.gtid.seqno);
     mysql_mutex_lock(&thd->LOCK_wsrep_thd);
     thd->wsrep_conflict_state = MUST_REPLAY;
-    DBUG_ASSERT(wsrep_thd_trx_seqno(thd) > 0);
+    assert(wsrep_thd_trx_seqno(thd) > 0);
     mysql_mutex_unlock(&thd->LOCK_wsrep_thd);
     mysql_mutex_lock(&LOCK_wsrep_replaying);
     wsrep_replaying++;
@@ -1193,7 +1193,7 @@ enum wsrep_trx_status wsrep_pre_commit(THD *thd)
       meta.gtid= WSREP_GTID_UNDEFINED;
       wsrep_xid_init(thd->get_transaction()->xid_state()->get_xid(),
                      meta.gtid.uuid, meta.gtid.seqno);
-      DBUG_ASSERT(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
+      assert(thd->wsrep_trx_meta.gtid.seqno != WSREP_SEQNO_UNDEFINED);
     }
     //fallthrough
 
@@ -1204,7 +1204,7 @@ enum wsrep_trx_status wsrep_pre_commit(THD *thd)
                 WSREP_QUERY(thd));
     DBUG_PRINT("wsrep", ("pre-commit fail"));
 
-    thd->wsrep_query_state= QUERY_EXEC;
+    wsrep_thd_set_query_state(thd, QUERY_EXEC);
 
     if (thd->wsrep_conflict_state == MUST_ABORT) {
       thd->wsrep_conflict_state= ABORTED;
@@ -1250,9 +1250,9 @@ bool wsrep_replicate_GTID(THD *thd)
   if (thd->slave_thread)
   {
     WSREP_DEBUG("GTID replication");
-    DBUG_ASSERT (WSREP_UNDEFINED_TRX_ID == thd->wsrep_ws_handle.trx_id);
+    assert (WSREP_UNDEFINED_TRX_ID == thd->wsrep_ws_handle.trx_id);
     (void)wsrep_ws_handle_for_trx(&thd->wsrep_ws_handle, thd->query_id);
-    DBUG_ASSERT (WSREP_UNDEFINED_TRX_ID != thd->wsrep_ws_handle.trx_id);
+    assert (WSREP_UNDEFINED_TRX_ID != thd->wsrep_ws_handle.trx_id);
     WSREP_DEBUG("slave trx using query ID %lu for replicating GTID",
                 (long unsigned int) thd->wsrep_ws_handle.trx_id);
 
