@@ -116,6 +116,7 @@ extern const char wsrep_defaults_group_suffix[];
 #define WSREP_SST_OPT_PARENT   "--parent"
 #define WSREP_SST_OPT_BINLOG   "--binlog"
 #define WSREP_SST_OPT_VERSION  "--mysqld-version"
+#define WSREP_SST_OPT_DEBUG    "--debug"
 
 // mysqldump-specific options
 #define WSREP_SST_OPT_USER     "--user"
@@ -566,7 +567,7 @@ static char* my_fgets (char* buf, size_t buf_len, FILE* stream)
  */
 static int generate_binlog_opt_val(char** ret)
 {
-  DBUG_ASSERT(ret);
+  assert(ret);
   *ret= NULL;
   if (opt_bin_log && get_gtid_mode(GTID_MODE_LOCK_NONE) > GTID_MODE_OFF)
   {
@@ -1439,6 +1440,10 @@ static int sst_donate_other (const char*   method,
                  binlog_opt, binlog_opt_val,
                  uuid, (long long) seqno,
                  bypass ? " " WSREP_SST_OPT_BYPASS : "");
+  DBUG_EXECUTE_IF("wsrep_sst_donor_skip", {
+    ret= snprintf(cmd_str() + strlen(cmd_str()), cmd_len - strlen(cmd_str()),
+                  WSREP_SST_OPT_DEBUG " '%s'", "wsrep_sst_donor_skip");
+  });
   my_free(binlog_opt_val);
 
   if (ret < 0 || ret >= cmd_len)
@@ -1614,7 +1619,7 @@ wsrep_cb_status_t wsrep_sst_donate_cb (void* app_ctx, void* recv_ctx,
   /* Above methods should return 0 in case of success and negative value
    * in case of failure. If we have any positive value here it means that we
    * handle errors in above functions in the wrong way */
-  DBUG_ASSERT(ret <= 0); 
+  assert(ret <= 0);
   return (ret >= 0 ? WSREP_CB_SUCCESS : WSREP_CB_FAILURE);
 }
 
