@@ -74,9 +74,9 @@ static int rdb_i_s_cfstats_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
-  DBUG_ASSERT(tables->table->field != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
+  assert(tables->table->field != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -130,7 +130,7 @@ static int rdb_i_s_cfstats_fill_table(
   const Rdb_cf_manager &cf_manager = rdb_get_cf_manager();
 
   for (const auto &cf_name : cf_manager.get_cf_names()) {
-    DBUG_ASSERT(!cf_name.empty());
+    assert(!cf_name.empty());
     std::shared_ptr<rocksdb::ColumnFamilyHandle> cfh =
         cf_manager.get_cf(cf_name);
     if (!cfh) {
@@ -165,7 +165,7 @@ static int rdb_i_s_cfstats_fill_table(
 static int rdb_i_s_cfstats_init(void *p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -194,9 +194,9 @@ static int rdb_i_s_dbstats_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
-  DBUG_ASSERT(tables->table->field != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
+  assert(tables->table->field != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -265,7 +265,7 @@ static int rdb_i_s_dbstats_fill_table(
 static int rdb_i_s_dbstats_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -298,9 +298,9 @@ static int rdb_i_s_perf_context_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -312,7 +312,7 @@ static int rdb_i_s_perf_context_fill_table(
   }
 
   Field **field = tables->table->field;
-  DBUG_ASSERT(field != nullptr);
+  assert(field != nullptr);
 
   rocksdb::DB *const rdb = rdb_get_rocksdb_db();
 
@@ -374,7 +374,7 @@ static int rdb_i_s_perf_context_fill_table(
 static int rdb_i_s_perf_context_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -403,10 +403,10 @@ static int rdb_i_s_perf_context_global_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
-  DBUG_ASSERT(tables->table->field != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
+  assert(tables->table->field != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -448,7 +448,7 @@ static int rdb_i_s_perf_context_global_fill_table(
 static int rdb_i_s_perf_context_global_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -478,8 +478,8 @@ static int rdb_i_s_cfoptions_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -502,7 +502,7 @@ static int rdb_i_s_cfoptions_fill_table(
     std::string val;
     rocksdb::ColumnFamilyOptions opts;
 
-    DBUG_ASSERT(!cf_name.empty());
+    assert(!cf_name.empty());
     cf_manager.get_cf_options(cf_name, &opts);
 
     std::vector<std::pair<std::string, std::string>> cf_option_types = {
@@ -705,8 +705,8 @@ static int rdb_i_s_cfoptions_fill_table(
     }
 
     for (const auto &cf_option_type : cf_option_types) {
-      DBUG_ASSERT(tables->table != nullptr);
-      DBUG_ASSERT(tables->table->field != nullptr);
+      assert(tables->table != nullptr);
+      assert(tables->table->field != nullptr);
 
       tables->table->field[RDB_CFOPTIONS_FIELD::CF_NAME]->store(
           cf_name.c_str(), cf_name.size(), system_charset_info);
@@ -752,15 +752,15 @@ static int rdb_global_info_fill_row(my_core::THD *const thd,
                                     const char *const type,
                                     const char *const name,
                                     const char *const value) {
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
-  DBUG_ASSERT(type != nullptr);
-  DBUG_ASSERT(name != nullptr);
-  DBUG_ASSERT(value != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
+  assert(type != nullptr);
+  assert(name != nullptr);
+  assert(value != nullptr);
 
   Field **field = tables->table->field;
-  DBUG_ASSERT(field != nullptr);
+  assert(field != nullptr);
 
   field[RDB_GLOBAL_INFO_FIELD::TYPE]->store(type, strlen(type),
                                             system_charset_info);
@@ -777,8 +777,8 @@ static int rdb_i_s_global_info_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
 
   static const uint32_t INT_BUF_LEN = 21;
   static const uint32_t CF_ID_INDEX_BUF_LEN = 60;
@@ -794,7 +794,7 @@ static int rdb_i_s_global_info_fill_table(
 
   /* max index info */
   Rdb_dict_manager *const dict_manager = rdb_get_dict_manager();
-  DBUG_ASSERT(dict_manager != nullptr);
+  assert(dict_manager != nullptr);
 
   uint32_t max_index_id;
   char max_index_id_buf[INT_BUF_LEN] = {0};
@@ -812,14 +812,14 @@ static int rdb_i_s_global_info_fill_table(
   const Rdb_cf_manager &cf_manager = rdb_get_cf_manager();
 
   for (const auto &cf_handle : cf_manager.get_all_cf()) {
-    DBUG_ASSERT(cf_handle != nullptr);
+    assert(cf_handle != nullptr);
 
     DBUG_EXECUTE_IF("information_schema_global_info", {
       if (cf_handle->GetName() == "cf_primary_key") {
         const char act[] =
             "now signal ready_to_mark_cf_dropped_in_global_info "
             "wait_for mark_cf_dropped_done_in_global_info";
-        DBUG_ASSERT(!debug_sync_set_action(thd, STRING_WITH_LEN(act)));
+        assert(!debug_sync_set_action(thd, STRING_WITH_LEN(act)));
       }
     });
 
@@ -871,8 +871,8 @@ static int rdb_i_s_global_info_fill_table(
 static int rdb_i_s_compact_stats_fill_table(
     my_core::THD *thd, my_core::TABLE_LIST *tables,
     my_core::Item *cond MY_ATTRIBUTE((__unused__))) {
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
 
   DBUG_ENTER_FUNC();
 
@@ -907,7 +907,7 @@ static int rdb_i_s_compact_stats_fill_table(
     bool bool_ret MY_ATTRIBUTE((__unused__));
     bool_ret = rdb->GetMapProperty(cfh.get(), "rocksdb.cfstats", &props);
 
-    DBUG_ASSERT(bool_ret);
+    assert(bool_ret);
 
     const std::string prop_name_prefix = "compaction.";
     for (auto const &prop_ent : props) {
@@ -917,13 +917,13 @@ static int rdb_i_s_compact_stats_fill_table(
       }
       std::string value = prop_ent.second;
       std::size_t del_pos = prop_name.find('.', prop_name_prefix.size());
-      DBUG_ASSERT(del_pos != std::string::npos);
+      assert(del_pos != std::string::npos);
       std::string level_str = prop_name.substr(
           prop_name_prefix.size(), del_pos - prop_name_prefix.size());
       std::string type_str = prop_name.substr(del_pos + 1);
 
       Field **field = tables->table->field;
-      DBUG_ASSERT(field != nullptr);
+      assert(field != nullptr);
 
       field[0]->store(cf_name.c_str(), cf_name.size(), system_charset_info);
       field[1]->store(level_str.c_str(), level_str.size(), system_charset_info);
@@ -998,13 +998,13 @@ static ST_FIELD_INFO rdb_i_s_ddl_fields_info[] = {
     ROCKSDB_FIELD_INFO_END};
 
 int Rdb_ddl_scanner::add_table(Rdb_tbl_def *tdef) {
-  DBUG_ASSERT(tdef != nullptr);
+  assert(tdef != nullptr);
 
   int ret = 0;
 
-  DBUG_ASSERT(m_table != nullptr);
+  assert(m_table != nullptr);
   Field **field = m_table->field;
-  DBUG_ASSERT(field != nullptr);
+  assert(field != nullptr);
   const Rdb_dict_manager *dict_manager = rdb_get_dict_manager();
 
   const std::string &dbname = tdef->base_dbname();
@@ -1062,9 +1062,9 @@ static int rdb_i_s_ddl_fill_table(my_core::THD *const thd,
                                   my_core::Item *const cond) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -1087,7 +1087,7 @@ static int rdb_i_s_ddl_fill_table(my_core::THD *const thd,
   ddl_arg.m_table = tables->table;
 
   Rdb_ddl_manager *ddl_manager = rdb_get_ddl_manager();
-  DBUG_ASSERT(ddl_manager != nullptr);
+  assert(ddl_manager != nullptr);
 
   ret = ddl_manager->scan_for_tables(&ddl_arg);
 
@@ -1099,7 +1099,7 @@ static int rdb_i_s_ddl_init(void *const p) {
 
   my_core::ST_SCHEMA_TABLE *schema;
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   schema = (my_core::ST_SCHEMA_TABLE *)p;
 
@@ -1112,7 +1112,7 @@ static int rdb_i_s_ddl_init(void *const p) {
 static int rdb_i_s_cfoptions_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -1127,7 +1127,7 @@ static int rdb_i_s_cfoptions_init(void *const p) {
 static int rdb_i_s_global_info_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -1143,7 +1143,7 @@ static int rdb_i_s_compact_stats_init(void *p) {
   my_core::ST_SCHEMA_TABLE *schema;
 
   DBUG_ENTER_FUNC();
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   schema = reinterpret_cast<my_core::ST_SCHEMA_TABLE *>(p);
 
@@ -1227,9 +1227,9 @@ static int rdb_i_s_sst_props_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -1241,7 +1241,7 @@ static int rdb_i_s_sst_props_fill_table(
   }
 
   Field **field = tables->table->field;
-  DBUG_ASSERT(field != nullptr);
+  assert(field != nullptr);
 
   /* Iterate over all the column families */
   rocksdb::DB *const rdb = rdb_get_rocksdb_db();
@@ -1338,7 +1338,7 @@ static int rdb_i_s_sst_props_fill_table(
 static int rdb_i_s_sst_props_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -1397,9 +1397,9 @@ static int rdb_i_s_index_file_map_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -1411,7 +1411,7 @@ static int rdb_i_s_index_file_map_fill_table(
   }
 
   Field **field = tables->table->field;
-  DBUG_ASSERT(field != nullptr);
+  assert(field != nullptr);
 
   /* Iterate over all the column families */
   rocksdb::DB *const rdb = rdb_get_rocksdb_db();
@@ -1511,7 +1511,7 @@ static int rdb_i_s_index_file_map_fill_table(
 static int rdb_i_s_index_file_map_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -1544,10 +1544,10 @@ static int rdb_i_s_lock_info_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
-  DBUG_ASSERT(tables->table->field != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
+  assert(tables->table->field != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -1601,7 +1601,7 @@ static int rdb_i_s_lock_info_fill_table(
 static int rdb_i_s_lock_info_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -1665,10 +1665,10 @@ static int rdb_i_s_trx_info_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
-  DBUG_ASSERT(tables->table->field != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
+  assert(tables->table->field != nullptr);
 
   int ret = 0;
   Rdb_hton_init_state::Scoped_lock state_lock(*rdb_get_hton_init_state(),
@@ -1739,7 +1739,7 @@ static int rdb_i_s_trx_info_fill_table(
 static int rdb_i_s_trx_info_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
@@ -1789,10 +1789,10 @@ static int rdb_i_s_deadlock_info_fill_table(
     my_core::Item *const cond MY_ATTRIBUTE((__unused__))) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(thd != nullptr);
-  DBUG_ASSERT(tables != nullptr);
-  DBUG_ASSERT(tables->table != nullptr);
-  DBUG_ASSERT(tables->table->field != nullptr);
+  assert(thd != nullptr);
+  assert(tables != nullptr);
+  assert(tables->table != nullptr);
+  assert(tables->table->field != nullptr);
 
   static const std::string str_exclusive("EXCLUSIVE");
   static const std::string str_shared("SHARED");
@@ -1863,7 +1863,7 @@ static int rdb_i_s_deadlock_info_fill_table(
 static int rdb_i_s_deadlock_info_init(void *const p) {
   DBUG_ENTER_FUNC();
 
-  DBUG_ASSERT(p != nullptr);
+  assert(p != nullptr);
 
   my_core::ST_SCHEMA_TABLE *schema;
 
